syncdrift_annotations library
Annotations for the syncdrift_flutter database framework.
Classes
- BelongsTo
- Defines a many-to-one relationship. Place this on a Table class to declare that it "belongs to" the targetTable.
- Cached
- Enable smart caching for a table.
- HasMany
- Defines a one-to-many relationship. Place this on a Table class to declare that it "has many" of the targetTable.
- Repository
-
Annotate a Drift Table class with
@Repository()to trigger code generation of a dedicated Repository class. - SyncTable
- Enable offline-first synchronization for a table.